.ig
Copyright (C) 2002  Ben Kibbey <bjk@arbornet.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
..
.TH bubblegum 8 %date% %version%
.SH NAME
.
bubblegum - Watch a file for changes.
.
.SH SYNOPSIS
.
.B bubblegum 
[
.B -hvksq
] [
.BI -l \ logfile
] [
.BI - loglevel
] [
.BI -e \ command
] [
.BI -r \ runs
|
.BI -t \ runs
] [
.BI -n \ niceness
] [
.BI -i \ seconds
] [
.BI -p \ pidfile
] [
.B -M
] [
.B -A
|
.B -amcE
]
.B -f
.IR filelist
|
.IR file
.IR [...]
.
.SH DESCRIPTION
.
.B bubblegum
is a daemon which watches a files access, modification and inode change times
and logs those changes. Filenames obtained from a file list via the 
.B -f
option or from the command line are relative to the current directory unless
they begin with a `/' in which case the full pathname to the file is used.
.
.SH OPTIONS
.
.TP
.BI -f \ filename
Obtain a list of files to watch, one per line, from
.IR filename .
.TP
.BI -n \ level
The priority or niceness level,
.I -20
through
.IR 20 ,
of the daemon process and executed commands. Only the super-user can set a
priority lower than the parent process.
.TP
.BI -i \ seconds
Interval in seconds to wait between file checks. Must be greater than
.IR 0 .
The default is
.IR 1 .
.TP
.B -a
Check the acces time of the file.
.TP
.B -m
Check the modification time of the file.
.TP 
.B -c
Check the inode change time of the file.
.TP
.B -M
Check the MD5 checksum of the file. The files checksum is updated after
detecting a change. The files modification time is used as the time
difference. Note that both MD5 and access time checking
.B -a
cannot be specified because MD5 checking modifies the access time. Also note
that this option increases CPU overhead significantly, escpecially with a
short time interval and lots of files. This option is only available if
compiled with libmd support.
.TP
.B -E
Check for errors when accessing the file via
.BR stat (2).
.TP
.B -A
Check everything except MD5 checksums. This option is a shortcut for
specifying
.BR -amcE .
.TP
.BI -e \ command
Execute a command via 
.BR execvp (3)
after detecting a file change. Any arguments to 
.I command
which contain spaces must be enclosed in double quotes `"' to keep the
argument list sane. To include a double quote or backslash character in an
argument itself, precede it with a backslash `\\' character. See
.B COMMAND EXPANSIONS 
below for special character expansions.
.TP
.BI -r \ runs
Maximum number of times to run
.B command 
for each file. A setting of 
.I 0 
will run
.B command
an infinite number of times. The default is
.IR 1 .
.TP
.BI -t \ runs
Total number of times to run 
.BR command .
This option overrides
.BR -r .
.TP
.BI -l \ logfile
Log changes to the specified 
.IR logfile . 
The default is
.IR ~/bubblegum.log .
See
.B ENVIRONMENT VARIABLES
and
.B FILES
below.
.TP
.BI - loglevel
Logging level. A value of
.I 0
will disable file logging. A value of 
.I 1 
will log only the first change of each file. A value of
.I 2
will log all changes of all files up to an error if error checking is enabled.
If the error changes, then the error is logged. If the error disappears, then
logging for that file continues as normal. The default is
.IR 2 .
.TP
.B -s
Enable logging to
.BR syslogd (8)
and disable file logging. Note that the 
.BI - loglevel
option still applies.
.TP
.B -k
If a file is a symbolic link, check the link itself, not the file the link
follows.
.TP
.BI -p \ pidfile
An alternate process id file to use.
.TP
.B -q
Terminate an already running daemon.
.TP
.B -h
Program help text.
.TP
.B -v
Version and copyright information.
.
.SH COMMAND EXPANSIONS
When specifying a command with the
.B -e
option, special character expansions are available to show information about
a files change. The following expansions are available and each should be
enclosed in double quotes `"' to keep the argument list sane (see
.B EXAMPLES
below):
.TP
.B %f
Full path of the filename.
.TP
.B %F
The type of file (DIRECTORY, FIFO, ...).
.TP
.B %m
File permission mode in octal.
.TP
.B %t
Time stamp of the latest change.
.TP
.B %b
Time of the last change.
.TP
.B %d
Time stamp of when the change was detected.
.TP
.B %i
Time difference of the latest and last change in
.I days:hours:minutes:seconds 
format.
.TP
.B %s
Daemon status information.
.TP
.B %p
Daemon process id (PID).
.TP
.B %c
A comma separated list of changes:
.IR ATIME ,
.IR MTIME , 
.IR CTIME ,
.I MD5
or
.IR ERROR .
.TP
.B %y
A comma separated list of the type of change if available. The recognized
change types are: 
.IR IDEV ,
.IR INODE ,
.IR HLINK ,
.IR USER ,
.IR GROUP ,
.IR PERM 
and
.IR SIZE .
If no change type is available then a single `-' is used. See 
.BR stat (2)
for definitions of the change types.
.TP
.B %e
If an error occurs while accessing the file with the
.BR stat (2)
system call, and error checking has been enabled with the
.B -E
option, then this is expanded to the error string via
.BR strerror (3).
Otherwise it holds a single `-' character.
.TP
.B %r
The number of times the 
.B command 
has been run and the total number of times
allowed specified with the
.B -r
or
.B -t
command line options.
.TP
.B %%
A regular `%' character.
.
.SH EXAMPLES
.TP
bubblegum -e 'script.sh "%f" "%c" "%y"' -As -f filelist
.
.SH ENVIRONMENT VARIABLES
.TP
.B BUBBLEGUM_LOG
Logging file. Command line option
.B -l
will override this variable.
.TP
.B BUBBLEGUM_PID
Process ID file. Command line option
.B -p
will override this variable.
.
.SH FILES
.TP
.B ~/bubblegum.log
Logging file if none is specified with the 
.B -l
command line option and the
.B BUBBLEGUM_LOG
environment variable is unset and logging to
.BR syslogd (8)
is disabled.
.TP
.B ~/bubblegum.pid
Process ID file if none is specified with the
.B -p
command line option and the
.B BUBBLEGUM_PID
enviroment variable is unset.
.
.SH SIGNALS
.
The following signals are caught:
.TP
.B SIGALRM
Force the current timer to expire causing the next file check.
.TP
.B SIGHUP
Reload the file list specified with the 
.B -f
option keeping the original changed bits and command runs for existing files.
.TP
.B SIGUSR1
Reset only the changed bits for all files.
.TP
.B SIGUSR2
Reset changed bits, command runs and total command runs for all files.
.TP
.B SIGTERM
Terminate the daemon.
.ig 
.TP
.B SIGCHLD
Used with a command specified with the
.B -e
command line option.
..
.
.SH SEE ALSO
.BR stat (2),
.BR MD5File (3),
.BR setpriority (2),
.BR fork (2),
.BR select (2),
.BR syslogd (8),
.BR execvp (3)
.
.SH AUTHOR
.
Copyright (C) 2002 Ben Kibbey <bjk@arbornet.org>. Distributed under the terms
of the GNU General Public License version 2.
